# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DiAlarmRuleArgs', 'DiAlarmRule']

@pulumi.input_type
class DiAlarmRuleArgs:
    def __init__(__self__, *,
                 di_alarm_rule_name: pulumi.Input[builtins.str],
                 di_job_id: pulumi.Input[builtins.int],
                 metric_type: pulumi.Input[builtins.str],
                 notification_settings: pulumi.Input['DiAlarmRuleNotificationSettingsArgs'],
                 trigger_conditions: pulumi.Input[Sequence[pulumi.Input['DiAlarmRuleTriggerConditionArgs']]],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a DiAlarmRule resource.
        :param pulumi.Input[builtins.str] di_alarm_rule_name: Data Integration alarm rule name
        :param pulumi.Input[builtins.int] di_job_id: Task ID: the ID of the task associated with the alert rule.
        :param pulumi.Input[builtins.str] metric_type: Alarm indicator type. Optional enumerated values:
               - Heartbeat (task status alarm)
               - FailoverCount(failover times alarm)
               - Delay (task Delay alarm)
        :param pulumi.Input['DiAlarmRuleNotificationSettingsArgs'] notification_settings: Alarm notification settings See `notification_settings` below.
        :param pulumi.Input[Sequence[pulumi.Input['DiAlarmRuleTriggerConditionArgs']]] trigger_conditions: Alarm trigger condition list, supporting multiple conditions See `trigger_conditions` below.
        """
        pulumi.set(__self__, "di_alarm_rule_name", di_alarm_rule_name)
        pulumi.set(__self__, "di_job_id", di_job_id)
        pulumi.set(__self__, "metric_type", metric_type)
        pulumi.set(__self__, "notification_settings", notification_settings)
        pulumi.set(__self__, "trigger_conditions", trigger_conditions)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)

    @property
    @pulumi.getter(name="diAlarmRuleName")
    def di_alarm_rule_name(self) -> pulumi.Input[builtins.str]:
        """
        Data Integration alarm rule name
        """
        return pulumi.get(self, "di_alarm_rule_name")

    @di_alarm_rule_name.setter
    def di_alarm_rule_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "di_alarm_rule_name", value)

    @property
    @pulumi.getter(name="diJobId")
    def di_job_id(self) -> pulumi.Input[builtins.int]:
        """
        Task ID: the ID of the task associated with the alert rule.
        """
        return pulumi.get(self, "di_job_id")

    @di_job_id.setter
    def di_job_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "di_job_id", value)

    @property
    @pulumi.getter(name="metricType")
    def metric_type(self) -> pulumi.Input[builtins.str]:
        """
        Alarm indicator type. Optional enumerated values:
        - Heartbeat (task status alarm)
        - FailoverCount(failover times alarm)
        - Delay (task Delay alarm)
        """
        return pulumi.get(self, "metric_type")

    @metric_type.setter
    def metric_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "metric_type", value)

    @property
    @pulumi.getter(name="notificationSettings")
    def notification_settings(self) -> pulumi.Input['DiAlarmRuleNotificationSettingsArgs']:
        """
        Alarm notification settings See `notification_settings` below.
        """
        return pulumi.get(self, "notification_settings")

    @notification_settings.setter
    def notification_settings(self, value: pulumi.Input['DiAlarmRuleNotificationSettingsArgs']):
        pulumi.set(self, "notification_settings", value)

    @property
    @pulumi.getter(name="triggerConditions")
    def trigger_conditions(self) -> pulumi.Input[Sequence[pulumi.Input['DiAlarmRuleTriggerConditionArgs']]]:
        """
        Alarm trigger condition list, supporting multiple conditions See `trigger_conditions` below.
        """
        return pulumi.get(self, "trigger_conditions")

    @trigger_conditions.setter
    def trigger_conditions(self, value: pulumi.Input[Sequence[pulumi.Input['DiAlarmRuleTriggerConditionArgs']]]):
        pulumi.set(self, "trigger_conditions", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)


@pulumi.input_type
class _DiAlarmRuleState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 di_alarm_rule_id: Optional[pulumi.Input[builtins.int]] = None,
                 di_alarm_rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 di_job_id: Optional[pulumi.Input[builtins.int]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 metric_type: Optional[pulumi.Input[builtins.str]] = None,
                 notification_settings: Optional[pulumi.Input['DiAlarmRuleNotificationSettingsArgs']] = None,
                 trigger_conditions: Optional[pulumi.Input[Sequence[pulumi.Input['DiAlarmRuleTriggerConditionArgs']]]] = None):
        """
        Input properties used for looking up and filtering DiAlarmRule resources.
        :param pulumi.Input[builtins.int] di_alarm_rule_id: Resource attribute field representing resource level ID
        :param pulumi.Input[builtins.str] di_alarm_rule_name: Data Integration alarm rule name
        :param pulumi.Input[builtins.int] di_job_id: Task ID: the ID of the task associated with the alert rule.
        :param pulumi.Input[builtins.str] metric_type: Alarm indicator type. Optional enumerated values:
               - Heartbeat (task status alarm)
               - FailoverCount(failover times alarm)
               - Delay (task Delay alarm)
        :param pulumi.Input['DiAlarmRuleNotificationSettingsArgs'] notification_settings: Alarm notification settings See `notification_settings` below.
        :param pulumi.Input[Sequence[pulumi.Input['DiAlarmRuleTriggerConditionArgs']]] trigger_conditions: Alarm trigger condition list, supporting multiple conditions See `trigger_conditions` below.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if di_alarm_rule_id is not None:
            pulumi.set(__self__, "di_alarm_rule_id", di_alarm_rule_id)
        if di_alarm_rule_name is not None:
            pulumi.set(__self__, "di_alarm_rule_name", di_alarm_rule_name)
        if di_job_id is not None:
            pulumi.set(__self__, "di_job_id", di_job_id)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if metric_type is not None:
            pulumi.set(__self__, "metric_type", metric_type)
        if notification_settings is not None:
            pulumi.set(__self__, "notification_settings", notification_settings)
        if trigger_conditions is not None:
            pulumi.set(__self__, "trigger_conditions", trigger_conditions)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="diAlarmRuleId")
    def di_alarm_rule_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Resource attribute field representing resource level ID
        """
        return pulumi.get(self, "di_alarm_rule_id")

    @di_alarm_rule_id.setter
    def di_alarm_rule_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "di_alarm_rule_id", value)

    @property
    @pulumi.getter(name="diAlarmRuleName")
    def di_alarm_rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Data Integration alarm rule name
        """
        return pulumi.get(self, "di_alarm_rule_name")

    @di_alarm_rule_name.setter
    def di_alarm_rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "di_alarm_rule_name", value)

    @property
    @pulumi.getter(name="diJobId")
    def di_job_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Task ID: the ID of the task associated with the alert rule.
        """
        return pulumi.get(self, "di_job_id")

    @di_job_id.setter
    def di_job_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "di_job_id", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="metricType")
    def metric_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Alarm indicator type. Optional enumerated values:
        - Heartbeat (task status alarm)
        - FailoverCount(failover times alarm)
        - Delay (task Delay alarm)
        """
        return pulumi.get(self, "metric_type")

    @metric_type.setter
    def metric_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "metric_type", value)

    @property
    @pulumi.getter(name="notificationSettings")
    def notification_settings(self) -> Optional[pulumi.Input['DiAlarmRuleNotificationSettingsArgs']]:
        """
        Alarm notification settings See `notification_settings` below.
        """
        return pulumi.get(self, "notification_settings")

    @notification_settings.setter
    def notification_settings(self, value: Optional[pulumi.Input['DiAlarmRuleNotificationSettingsArgs']]):
        pulumi.set(self, "notification_settings", value)

    @property
    @pulumi.getter(name="triggerConditions")
    def trigger_conditions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DiAlarmRuleTriggerConditionArgs']]]]:
        """
        Alarm trigger condition list, supporting multiple conditions See `trigger_conditions` below.
        """
        return pulumi.get(self, "trigger_conditions")

    @trigger_conditions.setter
    def trigger_conditions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DiAlarmRuleTriggerConditionArgs']]]]):
        pulumi.set(self, "trigger_conditions", value)


@pulumi.type_token("alicloud:dataworks/diAlarmRule:DiAlarmRule")
class DiAlarmRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 di_alarm_rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 di_job_id: Optional[pulumi.Input[builtins.int]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 metric_type: Optional[pulumi.Input[builtins.str]] = None,
                 notification_settings: Optional[pulumi.Input[Union['DiAlarmRuleNotificationSettingsArgs', 'DiAlarmRuleNotificationSettingsArgsDict']]] = None,
                 trigger_conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DiAlarmRuleTriggerConditionArgs', 'DiAlarmRuleTriggerConditionArgsDict']]]]] = None,
                 __props__=None):
        """
        Provides a Data Works Di Alarm Rule resource.

        Data Integration alarm rules.

        For information about Data Works Di Alarm Rule and how to use it, see [What is Di Alarm Rule](https://www.alibabacloud.com/help/en/dataworks/developer-reference/api-dataworks-public-2024-05-18-createdialarmrule).

        > **NOTE:** Available since v1.241.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform_example"
        defaulte_nv8bu = alicloud.dataworks.Project("defaulteNv8bu",
            project_name=name,
            display_name=name,
            description=name,
            pai_task_enabled=True)
        default_uw8inp = alicloud.dataworks.DiJob("defaultUW8inp",
            description="xxxx",
            project_id=defaulte_nv8bu.id,
            job_name="xxx",
            migration_type="api_xxx",
            source_data_source_type="xxx",
            resource_settings={
                "offline_resource_settings": {
                    "requested_cu": 2,
                    "resource_group_identifier": "xx",
                },
                "realtime_resource_settings": {
                    "requested_cu": 2,
                    "resource_group_identifier": "xx",
                },
                "schedule_resource_settings": {
                    "requested_cu": 2,
                    "resource_group_identifier": "xx",
                },
            },
            job_settings={
                "channel_settings": "xxxx",
                "column_data_type_settings": [{
                    "destination_data_type": "xxxx",
                    "source_data_type": "xxxx",
                }],
                "cycle_schedule_settings": {
                    "cycle_migration_type": "xxxx",
                    "schedule_parameters": "xxxx",
                },
            },
            source_data_source_settings=[{
                "data_source_name": "xxxx",
                "data_source_properties": {
                    "encoding": "xxxx",
                    "timezone": "xxxx",
                },
            }],
            destination_data_source_type="xxxx",
            table_mappings=[{
                "source_object_selection_rules": [
                    {
                        "action": "Include",
                        "expression": "xxxx",
                        "expression_type": "Exact",
                        "object_type": "xxxx",
                    },
                    {
                        "action": "Include",
                        "expression": "xxxx",
                        "expression_type": "Exact",
                        "object_type": "xxxx",
                    },
                ],
                "transformation_rules": [{
                    "rule_name": "xxxx",
                    "rule_action_type": "xxxx",
                    "rule_target_type": "xxxx",
                }],
            }],
            transformation_rules=[{
                "rule_action_type": "xxxx",
                "rule_expression": "xxxx",
                "rule_name": "xxxx",
                "rule_target_type": "xxxx",
            }],
            destination_data_source_settings=[{
                "data_source_name": "xxx",
            }])
        default = alicloud.dataworks.DiAlarmRule("default",
            description="Description",
            trigger_conditions=[{
                "ddl_report_tags": ["ALTERADDCOLUMN"],
                "threshold": 20,
                "duration": 10,
                "severity": "Warning",
            }],
            metric_type="DdlReport",
            notification_settings={
                "notification_channels": [{
                    "severity": "Warning",
                    "channels": ["Ding"],
                }],
                "notification_receivers": [{
                    "receiver_type": "DingToken",
                    "receiver_values": ["1107550004253538"],
                }],
                "inhibition_interval": 10,
            },
            di_job_id=default_uw8inp.di_job_id,
            di_alarm_rule_name=name)
        ```

        ## Import

        Data Works Di Alarm Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dataworks/diAlarmRule:DiAlarmRule example <di_job_id>:<di_alarm_rule_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] di_alarm_rule_name: Data Integration alarm rule name
        :param pulumi.Input[builtins.int] di_job_id: Task ID: the ID of the task associated with the alert rule.
        :param pulumi.Input[builtins.str] metric_type: Alarm indicator type. Optional enumerated values:
               - Heartbeat (task status alarm)
               - FailoverCount(failover times alarm)
               - Delay (task Delay alarm)
        :param pulumi.Input[Union['DiAlarmRuleNotificationSettingsArgs', 'DiAlarmRuleNotificationSettingsArgsDict']] notification_settings: Alarm notification settings See `notification_settings` below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DiAlarmRuleTriggerConditionArgs', 'DiAlarmRuleTriggerConditionArgsDict']]]] trigger_conditions: Alarm trigger condition list, supporting multiple conditions See `trigger_conditions` below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DiAlarmRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Data Works Di Alarm Rule resource.

        Data Integration alarm rules.

        For information about Data Works Di Alarm Rule and how to use it, see [What is Di Alarm Rule](https://www.alibabacloud.com/help/en/dataworks/developer-reference/api-dataworks-public-2024-05-18-createdialarmrule).

        > **NOTE:** Available since v1.241.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform_example"
        defaulte_nv8bu = alicloud.dataworks.Project("defaulteNv8bu",
            project_name=name,
            display_name=name,
            description=name,
            pai_task_enabled=True)
        default_uw8inp = alicloud.dataworks.DiJob("defaultUW8inp",
            description="xxxx",
            project_id=defaulte_nv8bu.id,
            job_name="xxx",
            migration_type="api_xxx",
            source_data_source_type="xxx",
            resource_settings={
                "offline_resource_settings": {
                    "requested_cu": 2,
                    "resource_group_identifier": "xx",
                },
                "realtime_resource_settings": {
                    "requested_cu": 2,
                    "resource_group_identifier": "xx",
                },
                "schedule_resource_settings": {
                    "requested_cu": 2,
                    "resource_group_identifier": "xx",
                },
            },
            job_settings={
                "channel_settings": "xxxx",
                "column_data_type_settings": [{
                    "destination_data_type": "xxxx",
                    "source_data_type": "xxxx",
                }],
                "cycle_schedule_settings": {
                    "cycle_migration_type": "xxxx",
                    "schedule_parameters": "xxxx",
                },
            },
            source_data_source_settings=[{
                "data_source_name": "xxxx",
                "data_source_properties": {
                    "encoding": "xxxx",
                    "timezone": "xxxx",
                },
            }],
            destination_data_source_type="xxxx",
            table_mappings=[{
                "source_object_selection_rules": [
                    {
                        "action": "Include",
                        "expression": "xxxx",
                        "expression_type": "Exact",
                        "object_type": "xxxx",
                    },
                    {
                        "action": "Include",
                        "expression": "xxxx",
                        "expression_type": "Exact",
                        "object_type": "xxxx",
                    },
                ],
                "transformation_rules": [{
                    "rule_name": "xxxx",
                    "rule_action_type": "xxxx",
                    "rule_target_type": "xxxx",
                }],
            }],
            transformation_rules=[{
                "rule_action_type": "xxxx",
                "rule_expression": "xxxx",
                "rule_name": "xxxx",
                "rule_target_type": "xxxx",
            }],
            destination_data_source_settings=[{
                "data_source_name": "xxx",
            }])
        default = alicloud.dataworks.DiAlarmRule("default",
            description="Description",
            trigger_conditions=[{
                "ddl_report_tags": ["ALTERADDCOLUMN"],
                "threshold": 20,
                "duration": 10,
                "severity": "Warning",
            }],
            metric_type="DdlReport",
            notification_settings={
                "notification_channels": [{
                    "severity": "Warning",
                    "channels": ["Ding"],
                }],
                "notification_receivers": [{
                    "receiver_type": "DingToken",
                    "receiver_values": ["1107550004253538"],
                }],
                "inhibition_interval": 10,
            },
            di_job_id=default_uw8inp.di_job_id,
            di_alarm_rule_name=name)
        ```

        ## Import

        Data Works Di Alarm Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dataworks/diAlarmRule:DiAlarmRule example <di_job_id>:<di_alarm_rule_id>
        ```

        :param str resource_name: The name of the resource.
        :param DiAlarmRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DiAlarmRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 di_alarm_rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 di_job_id: Optional[pulumi.Input[builtins.int]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 metric_type: Optional[pulumi.Input[builtins.str]] = None,
                 notification_settings: Optional[pulumi.Input[Union['DiAlarmRuleNotificationSettingsArgs', 'DiAlarmRuleNotificationSettingsArgsDict']]] = None,
                 trigger_conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DiAlarmRuleTriggerConditionArgs', 'DiAlarmRuleTriggerConditionArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DiAlarmRuleArgs.__new__(DiAlarmRuleArgs)

            __props__.__dict__["description"] = description
            if di_alarm_rule_name is None and not opts.urn:
                raise TypeError("Missing required property 'di_alarm_rule_name'")
            __props__.__dict__["di_alarm_rule_name"] = di_alarm_rule_name
            if di_job_id is None and not opts.urn:
                raise TypeError("Missing required property 'di_job_id'")
            __props__.__dict__["di_job_id"] = di_job_id
            __props__.__dict__["enabled"] = enabled
            if metric_type is None and not opts.urn:
                raise TypeError("Missing required property 'metric_type'")
            __props__.__dict__["metric_type"] = metric_type
            if notification_settings is None and not opts.urn:
                raise TypeError("Missing required property 'notification_settings'")
            __props__.__dict__["notification_settings"] = notification_settings
            if trigger_conditions is None and not opts.urn:
                raise TypeError("Missing required property 'trigger_conditions'")
            __props__.__dict__["trigger_conditions"] = trigger_conditions
            __props__.__dict__["di_alarm_rule_id"] = None
        super(DiAlarmRule, __self__).__init__(
            'alicloud:dataworks/diAlarmRule:DiAlarmRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            di_alarm_rule_id: Optional[pulumi.Input[builtins.int]] = None,
            di_alarm_rule_name: Optional[pulumi.Input[builtins.str]] = None,
            di_job_id: Optional[pulumi.Input[builtins.int]] = None,
            enabled: Optional[pulumi.Input[builtins.bool]] = None,
            metric_type: Optional[pulumi.Input[builtins.str]] = None,
            notification_settings: Optional[pulumi.Input[Union['DiAlarmRuleNotificationSettingsArgs', 'DiAlarmRuleNotificationSettingsArgsDict']]] = None,
            trigger_conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DiAlarmRuleTriggerConditionArgs', 'DiAlarmRuleTriggerConditionArgsDict']]]]] = None) -> 'DiAlarmRule':
        """
        Get an existing DiAlarmRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] di_alarm_rule_id: Resource attribute field representing resource level ID
        :param pulumi.Input[builtins.str] di_alarm_rule_name: Data Integration alarm rule name
        :param pulumi.Input[builtins.int] di_job_id: Task ID: the ID of the task associated with the alert rule.
        :param pulumi.Input[builtins.str] metric_type: Alarm indicator type. Optional enumerated values:
               - Heartbeat (task status alarm)
               - FailoverCount(failover times alarm)
               - Delay (task Delay alarm)
        :param pulumi.Input[Union['DiAlarmRuleNotificationSettingsArgs', 'DiAlarmRuleNotificationSettingsArgsDict']] notification_settings: Alarm notification settings See `notification_settings` below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DiAlarmRuleTriggerConditionArgs', 'DiAlarmRuleTriggerConditionArgsDict']]]] trigger_conditions: Alarm trigger condition list, supporting multiple conditions See `trigger_conditions` below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DiAlarmRuleState.__new__(_DiAlarmRuleState)

        __props__.__dict__["description"] = description
        __props__.__dict__["di_alarm_rule_id"] = di_alarm_rule_id
        __props__.__dict__["di_alarm_rule_name"] = di_alarm_rule_name
        __props__.__dict__["di_job_id"] = di_job_id
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["metric_type"] = metric_type
        __props__.__dict__["notification_settings"] = notification_settings
        __props__.__dict__["trigger_conditions"] = trigger_conditions
        return DiAlarmRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="diAlarmRuleId")
    def di_alarm_rule_id(self) -> pulumi.Output[builtins.int]:
        """
        Resource attribute field representing resource level ID
        """
        return pulumi.get(self, "di_alarm_rule_id")

    @property
    @pulumi.getter(name="diAlarmRuleName")
    def di_alarm_rule_name(self) -> pulumi.Output[builtins.str]:
        """
        Data Integration alarm rule name
        """
        return pulumi.get(self, "di_alarm_rule_name")

    @property
    @pulumi.getter(name="diJobId")
    def di_job_id(self) -> pulumi.Output[builtins.int]:
        """
        Task ID: the ID of the task associated with the alert rule.
        """
        return pulumi.get(self, "di_job_id")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[Optional[builtins.bool]]:
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="metricType")
    def metric_type(self) -> pulumi.Output[builtins.str]:
        """
        Alarm indicator type. Optional enumerated values:
        - Heartbeat (task status alarm)
        - FailoverCount(failover times alarm)
        - Delay (task Delay alarm)
        """
        return pulumi.get(self, "metric_type")

    @property
    @pulumi.getter(name="notificationSettings")
    def notification_settings(self) -> pulumi.Output['outputs.DiAlarmRuleNotificationSettings']:
        """
        Alarm notification settings See `notification_settings` below.
        """
        return pulumi.get(self, "notification_settings")

    @property
    @pulumi.getter(name="triggerConditions")
    def trigger_conditions(self) -> pulumi.Output[Sequence['outputs.DiAlarmRuleTriggerCondition']]:
        """
        Alarm trigger condition list, supporting multiple conditions See `trigger_conditions` below.
        """
        return pulumi.get(self, "trigger_conditions")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DiskArgs', 'Disk']

@pulumi.input_type
class DiskArgs:
    def __init__(__self__, *,
                 category: pulumi.Input[builtins.str],
                 ens_region_id: pulumi.Input[builtins.str],
                 payment_type: pulumi.Input[builtins.str],
                 disk_name: Optional[pulumi.Input[builtins.str]] = None,
                 encrypted: Optional[pulumi.Input[builtins.bool]] = None,
                 kms_key_id: Optional[pulumi.Input[builtins.str]] = None,
                 size: Optional[pulumi.Input[builtins.int]] = None,
                 snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a Disk resource.
        :param pulumi.Input[builtins.str] category: The category of the disk. Valid values: `cloud_efficiency` (high-efficiency cloud disk), `cloud_ssd` (full Flash cloud disk), `local_hdd` (local HDD), `local_ssd` (local ssd).
        :param pulumi.Input[builtins.str] ens_region_id: The ID of the edge node.
        :param pulumi.Input[builtins.str] payment_type: The billing method of the instance. Valid values: `PayAsYouGo`.
        :param pulumi.Input[builtins.str] disk_name: The name of the disk.
        :param pulumi.Input[builtins.bool] encrypted: Specifies whether to encrypt the new system disk. Valid values: `true`, `false`(default).
        :param pulumi.Input[builtins.str] kms_key_id: The ID of the KMS key used by the cloud disk. If `encrypted` is set to `true`, the service default key is used when KMSKeyId is empty.
        :param pulumi.Input[builtins.int] size: The size of the disk instance. Unit: GiB.
        :param pulumi.Input[builtins.str] snapshot_id: The ID of the snapshot used to create the cloud disk.
               
               The SnapshotId and Size parameters have the following limitations:
               - If the snapshot capacity corresponding to the `snapshot_id` parameter is greater than the specified `size` parameter, the Size of the cloud disk created is the Size of the specified snapshot.
               - If the snapshot capacity corresponding to the `snapshot_id` parameter is less than the set `size` parameter value, the Size of the cloud disk created is the specified `size` parameter value.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The label to which the instance is bound.
        """
        pulumi.set(__self__, "category", category)
        pulumi.set(__self__, "ens_region_id", ens_region_id)
        pulumi.set(__self__, "payment_type", payment_type)
        if disk_name is not None:
            pulumi.set(__self__, "disk_name", disk_name)
        if encrypted is not None:
            pulumi.set(__self__, "encrypted", encrypted)
        if kms_key_id is not None:
            pulumi.set(__self__, "kms_key_id", kms_key_id)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if snapshot_id is not None:
            pulumi.set(__self__, "snapshot_id", snapshot_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def category(self) -> pulumi.Input[builtins.str]:
        """
        The category of the disk. Valid values: `cloud_efficiency` (high-efficiency cloud disk), `cloud_ssd` (full Flash cloud disk), `local_hdd` (local HDD), `local_ssd` (local ssd).
        """
        return pulumi.get(self, "category")

    @category.setter
    def category(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "category", value)

    @property
    @pulumi.getter(name="ensRegionId")
    def ens_region_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the edge node.
        """
        return pulumi.get(self, "ens_region_id")

    @ens_region_id.setter
    def ens_region_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "ens_region_id", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Input[builtins.str]:
        """
        The billing method of the instance. Valid values: `PayAsYouGo`.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter(name="diskName")
    def disk_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the disk.
        """
        return pulumi.get(self, "disk_name")

    @disk_name.setter
    def disk_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "disk_name", value)

    @property
    @pulumi.getter
    def encrypted(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether to encrypt the new system disk. Valid values: `true`, `false`(default).
        """
        return pulumi.get(self, "encrypted")

    @encrypted.setter
    def encrypted(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "encrypted", value)

    @property
    @pulumi.getter(name="kmsKeyId")
    def kms_key_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the KMS key used by the cloud disk. If `encrypted` is set to `true`, the service default key is used when KMSKeyId is empty.
        """
        return pulumi.get(self, "kms_key_id")

    @kms_key_id.setter
    def kms_key_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kms_key_id", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The size of the disk instance. Unit: GiB.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the snapshot used to create the cloud disk.

        The SnapshotId and Size parameters have the following limitations:
        - If the snapshot capacity corresponding to the `snapshot_id` parameter is greater than the specified `size` parameter, the Size of the cloud disk created is the Size of the specified snapshot.
        - If the snapshot capacity corresponding to the `snapshot_id` parameter is less than the set `size` parameter value, the Size of the cloud disk created is the specified `size` parameter value.
        """
        return pulumi.get(self, "snapshot_id")

    @snapshot_id.setter
    def snapshot_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "snapshot_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The label to which the instance is bound.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _DiskState:
    def __init__(__self__, *,
                 category: Optional[pulumi.Input[builtins.str]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 disk_name: Optional[pulumi.Input[builtins.str]] = None,
                 encrypted: Optional[pulumi.Input[builtins.bool]] = None,
                 ens_region_id: Optional[pulumi.Input[builtins.str]] = None,
                 kms_key_id: Optional[pulumi.Input[builtins.str]] = None,
                 payment_type: Optional[pulumi.Input[builtins.str]] = None,
                 size: Optional[pulumi.Input[builtins.int]] = None,
                 snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Disk resources.
        :param pulumi.Input[builtins.str] category: The category of the disk. Valid values: `cloud_efficiency` (high-efficiency cloud disk), `cloud_ssd` (full Flash cloud disk), `local_hdd` (local HDD), `local_ssd` (local ssd).
        :param pulumi.Input[builtins.str] create_time: The time when the disk was created.
        :param pulumi.Input[builtins.str] disk_name: The name of the disk.
        :param pulumi.Input[builtins.bool] encrypted: Specifies whether to encrypt the new system disk. Valid values: `true`, `false`(default).
        :param pulumi.Input[builtins.str] ens_region_id: The ID of the edge node.
        :param pulumi.Input[builtins.str] kms_key_id: The ID of the KMS key used by the cloud disk. If `encrypted` is set to `true`, the service default key is used when KMSKeyId is empty.
        :param pulumi.Input[builtins.str] payment_type: The billing method of the instance. Valid values: `PayAsYouGo`.
        :param pulumi.Input[builtins.int] size: The size of the disk instance. Unit: GiB.
        :param pulumi.Input[builtins.str] snapshot_id: The ID of the snapshot used to create the cloud disk.
               
               The SnapshotId and Size parameters have the following limitations:
               - If the snapshot capacity corresponding to the `snapshot_id` parameter is greater than the specified `size` parameter, the Size of the cloud disk created is the Size of the specified snapshot.
               - If the snapshot capacity corresponding to the `snapshot_id` parameter is less than the set `size` parameter value, the Size of the cloud disk created is the specified `size` parameter value.
        :param pulumi.Input[builtins.str] status: The status of the disk.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The label to which the instance is bound.
        """
        if category is not None:
            pulumi.set(__self__, "category", category)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if disk_name is not None:
            pulumi.set(__self__, "disk_name", disk_name)
        if encrypted is not None:
            pulumi.set(__self__, "encrypted", encrypted)
        if ens_region_id is not None:
            pulumi.set(__self__, "ens_region_id", ens_region_id)
        if kms_key_id is not None:
            pulumi.set(__self__, "kms_key_id", kms_key_id)
        if payment_type is not None:
            pulumi.set(__self__, "payment_type", payment_type)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if snapshot_id is not None:
            pulumi.set(__self__, "snapshot_id", snapshot_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def category(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The category of the disk. Valid values: `cloud_efficiency` (high-efficiency cloud disk), `cloud_ssd` (full Flash cloud disk), `local_hdd` (local HDD), `local_ssd` (local ssd).
        """
        return pulumi.get(self, "category")

    @category.setter
    def category(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "category", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The time when the disk was created.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="diskName")
    def disk_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the disk.
        """
        return pulumi.get(self, "disk_name")

    @disk_name.setter
    def disk_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "disk_name", value)

    @property
    @pulumi.getter
    def encrypted(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether to encrypt the new system disk. Valid values: `true`, `false`(default).
        """
        return pulumi.get(self, "encrypted")

    @encrypted.setter
    def encrypted(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "encrypted", value)

    @property
    @pulumi.getter(name="ensRegionId")
    def ens_region_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the edge node.
        """
        return pulumi.get(self, "ens_region_id")

    @ens_region_id.setter
    def ens_region_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ens_region_id", value)

    @property
    @pulumi.getter(name="kmsKeyId")
    def kms_key_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the KMS key used by the cloud disk. If `encrypted` is set to `true`, the service default key is used when KMSKeyId is empty.
        """
        return pulumi.get(self, "kms_key_id")

    @kms_key_id.setter
    def kms_key_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kms_key_id", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The billing method of the instance. Valid values: `PayAsYouGo`.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The size of the disk instance. Unit: GiB.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the snapshot used to create the cloud disk.

        The SnapshotId and Size parameters have the following limitations:
        - If the snapshot capacity corresponding to the `snapshot_id` parameter is greater than the specified `size` parameter, the Size of the cloud disk created is the Size of the specified snapshot.
        - If the snapshot capacity corresponding to the `snapshot_id` parameter is less than the set `size` parameter value, the Size of the cloud disk created is the specified `size` parameter value.
        """
        return pulumi.get(self, "snapshot_id")

    @snapshot_id.setter
    def snapshot_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "snapshot_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the disk.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The label to which the instance is bound.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("alicloud:ens/disk:Disk")
class Disk(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 category: Optional[pulumi.Input[builtins.str]] = None,
                 disk_name: Optional[pulumi.Input[builtins.str]] = None,
                 encrypted: Optional[pulumi.Input[builtins.bool]] = None,
                 ens_region_id: Optional[pulumi.Input[builtins.str]] = None,
                 kms_key_id: Optional[pulumi.Input[builtins.str]] = None,
                 payment_type: Optional[pulumi.Input[builtins.str]] = None,
                 size: Optional[pulumi.Input[builtins.int]] = None,
                 snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        Provides a ENS Disk resource.

        The disk. When you use it for the first time, please contact the product classmates to add a resource whitelist.

        For information about ENS Disk and how to use it, see [What is Disk](https://www.alibabacloud.com/help/en/ens/developer-reference/api-ens-2017-11-10-createdisk).

        > **NOTE:** Available since v1.213.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.ens.Disk("default",
            category="cloud_ssd",
            size=20,
            payment_type="PayAsYouGo",
            ens_region_id="cn-chongqing-11")
        ```

        ## Import

        ENS Disk can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ens/disk:Disk example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] category: The category of the disk. Valid values: `cloud_efficiency` (high-efficiency cloud disk), `cloud_ssd` (full Flash cloud disk), `local_hdd` (local HDD), `local_ssd` (local ssd).
        :param pulumi.Input[builtins.str] disk_name: The name of the disk.
        :param pulumi.Input[builtins.bool] encrypted: Specifies whether to encrypt the new system disk. Valid values: `true`, `false`(default).
        :param pulumi.Input[builtins.str] ens_region_id: The ID of the edge node.
        :param pulumi.Input[builtins.str] kms_key_id: The ID of the KMS key used by the cloud disk. If `encrypted` is set to `true`, the service default key is used when KMSKeyId is empty.
        :param pulumi.Input[builtins.str] payment_type: The billing method of the instance. Valid values: `PayAsYouGo`.
        :param pulumi.Input[builtins.int] size: The size of the disk instance. Unit: GiB.
        :param pulumi.Input[builtins.str] snapshot_id: The ID of the snapshot used to create the cloud disk.
               
               The SnapshotId and Size parameters have the following limitations:
               - If the snapshot capacity corresponding to the `snapshot_id` parameter is greater than the specified `size` parameter, the Size of the cloud disk created is the Size of the specified snapshot.
               - If the snapshot capacity corresponding to the `snapshot_id` parameter is less than the set `size` parameter value, the Size of the cloud disk created is the specified `size` parameter value.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The label to which the instance is bound.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DiskArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ENS Disk resource.

        The disk. When you use it for the first time, please contact the product classmates to add a resource whitelist.

        For information about ENS Disk and how to use it, see [What is Disk](https://www.alibabacloud.com/help/en/ens/developer-reference/api-ens-2017-11-10-createdisk).

        > **NOTE:** Available since v1.213.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.ens.Disk("default",
            category="cloud_ssd",
            size=20,
            payment_type="PayAsYouGo",
            ens_region_id="cn-chongqing-11")
        ```

        ## Import

        ENS Disk can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ens/disk:Disk example <id>
        ```

        :param str resource_name: The name of the resource.
        :param DiskArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DiskArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 category: Optional[pulumi.Input[builtins.str]] = None,
                 disk_name: Optional[pulumi.Input[builtins.str]] = None,
                 encrypted: Optional[pulumi.Input[builtins.bool]] = None,
                 ens_region_id: Optional[pulumi.Input[builtins.str]] = None,
                 kms_key_id: Optional[pulumi.Input[builtins.str]] = None,
                 payment_type: Optional[pulumi.Input[builtins.str]] = None,
                 size: Optional[pulumi.Input[builtins.int]] = None,
                 snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DiskArgs.__new__(DiskArgs)

            if category is None and not opts.urn:
                raise TypeError("Missing required property 'category'")
            __props__.__dict__["category"] = category
            __props__.__dict__["disk_name"] = disk_name
            __props__.__dict__["encrypted"] = encrypted
            if ens_region_id is None and not opts.urn:
                raise TypeError("Missing required property 'ens_region_id'")
            __props__.__dict__["ens_region_id"] = ens_region_id
            __props__.__dict__["kms_key_id"] = kms_key_id
            if payment_type is None and not opts.urn:
                raise TypeError("Missing required property 'payment_type'")
            __props__.__dict__["payment_type"] = payment_type
            __props__.__dict__["size"] = size
            __props__.__dict__["snapshot_id"] = snapshot_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
        super(Disk, __self__).__init__(
            'alicloud:ens/disk:Disk',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            category: Optional[pulumi.Input[builtins.str]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            disk_name: Optional[pulumi.Input[builtins.str]] = None,
            encrypted: Optional[pulumi.Input[builtins.bool]] = None,
            ens_region_id: Optional[pulumi.Input[builtins.str]] = None,
            kms_key_id: Optional[pulumi.Input[builtins.str]] = None,
            payment_type: Optional[pulumi.Input[builtins.str]] = None,
            size: Optional[pulumi.Input[builtins.int]] = None,
            snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None) -> 'Disk':
        """
        Get an existing Disk resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] category: The category of the disk. Valid values: `cloud_efficiency` (high-efficiency cloud disk), `cloud_ssd` (full Flash cloud disk), `local_hdd` (local HDD), `local_ssd` (local ssd).
        :param pulumi.Input[builtins.str] create_time: The time when the disk was created.
        :param pulumi.Input[builtins.str] disk_name: The name of the disk.
        :param pulumi.Input[builtins.bool] encrypted: Specifies whether to encrypt the new system disk. Valid values: `true`, `false`(default).
        :param pulumi.Input[builtins.str] ens_region_id: The ID of the edge node.
        :param pulumi.Input[builtins.str] kms_key_id: The ID of the KMS key used by the cloud disk. If `encrypted` is set to `true`, the service default key is used when KMSKeyId is empty.
        :param pulumi.Input[builtins.str] payment_type: The billing method of the instance. Valid values: `PayAsYouGo`.
        :param pulumi.Input[builtins.int] size: The size of the disk instance. Unit: GiB.
        :param pulumi.Input[builtins.str] snapshot_id: The ID of the snapshot used to create the cloud disk.
               
               The SnapshotId and Size parameters have the following limitations:
               - If the snapshot capacity corresponding to the `snapshot_id` parameter is greater than the specified `size` parameter, the Size of the cloud disk created is the Size of the specified snapshot.
               - If the snapshot capacity corresponding to the `snapshot_id` parameter is less than the set `size` parameter value, the Size of the cloud disk created is the specified `size` parameter value.
        :param pulumi.Input[builtins.str] status: The status of the disk.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The label to which the instance is bound.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DiskState.__new__(_DiskState)

        __props__.__dict__["category"] = category
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["disk_name"] = disk_name
        __props__.__dict__["encrypted"] = encrypted
        __props__.__dict__["ens_region_id"] = ens_region_id
        __props__.__dict__["kms_key_id"] = kms_key_id
        __props__.__dict__["payment_type"] = payment_type
        __props__.__dict__["size"] = size
        __props__.__dict__["snapshot_id"] = snapshot_id
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        return Disk(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def category(self) -> pulumi.Output[builtins.str]:
        """
        The category of the disk. Valid values: `cloud_efficiency` (high-efficiency cloud disk), `cloud_ssd` (full Flash cloud disk), `local_hdd` (local HDD), `local_ssd` (local ssd).
        """
        return pulumi.get(self, "category")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        The time when the disk was created.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="diskName")
    def disk_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The name of the disk.
        """
        return pulumi.get(self, "disk_name")

    @property
    @pulumi.getter
    def encrypted(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Specifies whether to encrypt the new system disk. Valid values: `true`, `false`(default).
        """
        return pulumi.get(self, "encrypted")

    @property
    @pulumi.getter(name="ensRegionId")
    def ens_region_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the edge node.
        """
        return pulumi.get(self, "ens_region_id")

    @property
    @pulumi.getter(name="kmsKeyId")
    def kms_key_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the KMS key used by the cloud disk. If `encrypted` is set to `true`, the service default key is used when KMSKeyId is empty.
        """
        return pulumi.get(self, "kms_key_id")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Output[builtins.str]:
        """
        The billing method of the instance. Valid values: `PayAsYouGo`.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter
    def size(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The size of the disk instance. Unit: GiB.
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The ID of the snapshot used to create the cloud disk.

        The SnapshotId and Size parameters have the following limitations:
        - If the snapshot capacity corresponding to the `snapshot_id` parameter is greater than the specified `size` parameter, the Size of the cloud disk created is the Size of the specified snapshot.
        - If the snapshot capacity corresponding to the `snapshot_id` parameter is less than the set `size` parameter value, the Size of the cloud disk created is the specified `size` parameter value.
        """
        return pulumi.get(self, "snapshot_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the disk.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        The label to which the instance is bound.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetDispatchRulesResult',
    'AwaitableGetDispatchRulesResult',
    'get_dispatch_rules',
    'get_dispatch_rules_output',
]

@pulumi.output_type
class GetDispatchRulesResult:
    """
    A collection of values returned by getDispatchRules.
    """
    def __init__(__self__, dispatch_rule_name=None, enable_details=None, id=None, ids=None, name_regex=None, names=None, output_file=None, rules=None):
        if dispatch_rule_name and not isinstance(dispatch_rule_name, str):
            raise TypeError("Expected argument 'dispatch_rule_name' to be a str")
        pulumi.set(__self__, "dispatch_rule_name", dispatch_rule_name)
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if rules and not isinstance(rules, list):
            raise TypeError("Expected argument 'rules' to be a list")
        pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter(name="dispatchRuleName")
    def dispatch_rule_name(self) -> Optional[builtins.str]:
        """
        The name of the dispatch rule.
        """
        return pulumi.get(self, "dispatch_rule_name")

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[builtins.bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        """
        A list of Dispatch Rule names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def rules(self) -> Sequence['outputs.GetDispatchRulesRuleResult']:
        """
        A list of Arms Dispatch Rules. Each element contains the following attributes:
        """
        return pulumi.get(self, "rules")


class AwaitableGetDispatchRulesResult(GetDispatchRulesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDispatchRulesResult(
            dispatch_rule_name=self.dispatch_rule_name,
            enable_details=self.enable_details,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            rules=self.rules)


def get_dispatch_rules(dispatch_rule_name: Optional[builtins.str] = None,
                       enable_details: Optional[builtins.bool] = None,
                       ids: Optional[Sequence[builtins.str]] = None,
                       name_regex: Optional[builtins.str] = None,
                       output_file: Optional[builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDispatchRulesResult:
    """
    This data source provides the Arms Dispatch Rules of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.136.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.arms.AlertContact("default",
        alert_contact_name="example_value",
        email="example_value@aaa.com")
    default_alert_contact_group = alicloud.arms.AlertContactGroup("default",
        alert_contact_group_name="example_value",
        contact_ids=[default.id])
    default_dispatch_rule = alicloud.arms.DispatchRule("default",
        dispatch_rule_name="example_value",
        dispatch_type="CREATE_ALERT",
        group_rules=[{
            "group_wait_time": 5,
            "group_interval": 15,
            "repeat_interval": 100,
            "grouping_fields": ["alertname"],
        }],
        label_match_expression_grids=[{
            "label_match_expression_groups": [{
                "label_match_expressions": [{
                    "key": "_aliyun_arms_involvedObject_kind",
                    "value": "app",
                    "operator": "eq",
                }],
            }],
        }],
        notify_rules=[{
            "notify_objects": [
                {
                    "notify_object_id": default.id,
                    "notify_type": "ARMS_CONTACT",
                    "name": "example_value",
                },
                {
                    "notify_object_id": default_alert_contact_group.id,
                    "notify_type": "ARMS_CONTACT_GROUP",
                    "name": "example_value",
                },
            ],
            "notify_channels": [
                "dingTalk",
                "wechat",
            ],
            "notify_start_time": "10:00",
            "notify_end_time": "23:00",
        }])
    ids = alicloud.arms.get_dispatch_rules_output(ids=[default_dispatch_rule.id])
    pulumi.export("armsDispatchRuleId1", ids.rules[0].id)
    ```


    :param builtins.str dispatch_rule_name: The name of the dispatch rule.
    :param builtins.bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[builtins.str] ids: A list of dispatch rule id.
    :param builtins.str name_regex: A regex string to filter results by Dispatch Rule name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['dispatchRuleName'] = dispatch_rule_name
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:arms/getDispatchRules:getDispatchRules', __args__, opts=opts, typ=GetDispatchRulesResult).value

    return AwaitableGetDispatchRulesResult(
        dispatch_rule_name=pulumi.get(__ret__, 'dispatch_rule_name'),
        enable_details=pulumi.get(__ret__, 'enable_details'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        rules=pulumi.get(__ret__, 'rules'))
def get_dispatch_rules_output(dispatch_rule_name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                              enable_details: Optional[pulumi.Input[Optional[builtins.bool]]] = None,
                              ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                              name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                              output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDispatchRulesResult]:
    """
    This data source provides the Arms Dispatch Rules of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.136.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.arms.AlertContact("default",
        alert_contact_name="example_value",
        email="example_value@aaa.com")
    default_alert_contact_group = alicloud.arms.AlertContactGroup("default",
        alert_contact_group_name="example_value",
        contact_ids=[default.id])
    default_dispatch_rule = alicloud.arms.DispatchRule("default",
        dispatch_rule_name="example_value",
        dispatch_type="CREATE_ALERT",
        group_rules=[{
            "group_wait_time": 5,
            "group_interval": 15,
            "repeat_interval": 100,
            "grouping_fields": ["alertname"],
        }],
        label_match_expression_grids=[{
            "label_match_expression_groups": [{
                "label_match_expressions": [{
                    "key": "_aliyun_arms_involvedObject_kind",
                    "value": "app",
                    "operator": "eq",
                }],
            }],
        }],
        notify_rules=[{
            "notify_objects": [
                {
                    "notify_object_id": default.id,
                    "notify_type": "ARMS_CONTACT",
                    "name": "example_value",
                },
                {
                    "notify_object_id": default_alert_contact_group.id,
                    "notify_type": "ARMS_CONTACT_GROUP",
                    "name": "example_value",
                },
            ],
            "notify_channels": [
                "dingTalk",
                "wechat",
            ],
            "notify_start_time": "10:00",
            "notify_end_time": "23:00",
        }])
    ids = alicloud.arms.get_dispatch_rules_output(ids=[default_dispatch_rule.id])
    pulumi.export("armsDispatchRuleId1", ids.rules[0].id)
    ```


    :param builtins.str dispatch_rule_name: The name of the dispatch rule.
    :param builtins.bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[builtins.str] ids: A list of dispatch rule id.
    :param builtins.str name_regex: A regex string to filter results by Dispatch Rule name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['dispatchRuleName'] = dispatch_rule_name
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:arms/getDispatchRules:getDispatchRules', __args__, opts=opts, typ=GetDispatchRulesResult)
    return __ret__.apply(lambda __response__: GetDispatchRulesResult(
        dispatch_rule_name=pulumi.get(__response__, 'dispatch_rule_name'),
        enable_details=pulumi.get(__response__, 'enable_details'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        rules=pulumi.get(__response__, 'rules')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetInstancesResult',
    'AwaitableGetInstancesResult',
    'get_instances',
    'get_instances_output',
]

@pulumi.output_type
class GetInstancesResult:
    """
    A collection of values returned by getInstances.
    """
    def __init__(__self__, enable_details=None, id=None, ids=None, instances=None, name_regex=None, names=None, output_file=None, query_str=None, status=None, support_engine=None):
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if instances and not isinstance(instances, list):
            raise TypeError("Expected argument 'instances' to be a list")
        pulumi.set(__self__, "instances", instances)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if query_str and not isinstance(query_str, str):
            raise TypeError("Expected argument 'query_str' to be a str")
        pulumi.set(__self__, "query_str", query_str)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if support_engine and not isinstance(support_engine, int):
            raise TypeError("Expected argument 'support_engine' to be a int")
        pulumi.set(__self__, "support_engine", support_engine)

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[builtins.bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def instances(self) -> Sequence['outputs.GetInstancesInstanceResult']:
        return pulumi.get(self, "instances")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="queryStr")
    def query_str(self) -> Optional[builtins.str]:
        return pulumi.get(self, "query_str")

    @property
    @pulumi.getter
    def status(self) -> Optional[builtins.str]:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="supportEngine")
    def support_engine(self) -> Optional[builtins.int]:
        return pulumi.get(self, "support_engine")


class AwaitableGetInstancesResult(GetInstancesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstancesResult(
            enable_details=self.enable_details,
            id=self.id,
            ids=self.ids,
            instances=self.instances,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            query_str=self.query_str,
            status=self.status,
            support_engine=self.support_engine)


def get_instances(enable_details: Optional[builtins.bool] = None,
                  ids: Optional[Sequence[builtins.str]] = None,
                  name_regex: Optional[builtins.str] = None,
                  output_file: Optional[builtins.str] = None,
                  query_str: Optional[builtins.str] = None,
                  status: Optional[builtins.str] = None,
                  support_engine: Optional[builtins.int] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstancesResult:
    """
    This data source provides the Lindorm Instances of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.132.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.lindorm.get_instances()
    pulumi.export("lindormInstanceId1", ids.instances[0].id)
    name_regex = alicloud.lindorm.get_instances(name_regex="^my-Instance")
    pulumi.export("lindormInstanceId2", name_regex.instances[0].id)
    ```


    :param builtins.bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[builtins.str] ids: A list of Instance IDs.
    :param builtins.str name_regex: A regex string to filter results by Instance name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str query_str: The query str, which can use `instance_name` keyword for fuzzy search.
    :param builtins.str status: Instance status, Valid values: `ACTIVATION`, `DELETED`, `CREATING`, `CLASS_CHANGING`, `LOCKED`, `INSTANCE_LEVEL_MODIFY`, `NET_MODIFYING`, `RESIZING`, `RESTARTING`, `MINOR_VERSION_TRANSING`.
    :param builtins.int support_engine: The support engine. Valid values: `1` to `7`.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['queryStr'] = query_str
    __args__['status'] = status
    __args__['supportEngine'] = support_engine
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:lindorm/getInstances:getInstances', __args__, opts=opts, typ=GetInstancesResult).value

    return AwaitableGetInstancesResult(
        enable_details=pulumi.get(__ret__, 'enable_details'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        instances=pulumi.get(__ret__, 'instances'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        query_str=pulumi.get(__ret__, 'query_str'),
        status=pulumi.get(__ret__, 'status'),
        support_engine=pulumi.get(__ret__, 'support_engine'))
def get_instances_output(enable_details: Optional[pulumi.Input[Optional[builtins.bool]]] = None,
                         ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                         name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                         output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                         query_str: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                         status: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                         support_engine: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstancesResult]:
    """
    This data source provides the Lindorm Instances of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.132.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.lindorm.get_instances()
    pulumi.export("lindormInstanceId1", ids.instances[0].id)
    name_regex = alicloud.lindorm.get_instances(name_regex="^my-Instance")
    pulumi.export("lindormInstanceId2", name_regex.instances[0].id)
    ```


    :param builtins.bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[builtins.str] ids: A list of Instance IDs.
    :param builtins.str name_regex: A regex string to filter results by Instance name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str query_str: The query str, which can use `instance_name` keyword for fuzzy search.
    :param builtins.str status: Instance status, Valid values: `ACTIVATION`, `DELETED`, `CREATING`, `CLASS_CHANGING`, `LOCKED`, `INSTANCE_LEVEL_MODIFY`, `NET_MODIFYING`, `RESIZING`, `RESTARTING`, `MINOR_VERSION_TRANSING`.
    :param builtins.int support_engine: The support engine. Valid values: `1` to `7`.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['queryStr'] = query_str
    __args__['status'] = status
    __args__['supportEngine'] = support_engine
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:lindorm/getInstances:getInstances', __args__, opts=opts, typ=GetInstancesResult)
    return __ret__.apply(lambda __response__: GetInstancesResult(
        enable_details=pulumi.get(__response__, 'enable_details'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        instances=pulumi.get(__response__, 'instances'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        query_str=pulumi.get(__response__, 'query_str'),
        status=pulumi.get(__response__, 'status'),
        support_engine=pulumi.get(__response__, 'support_engine')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetBackupPlansResult',
    'AwaitableGetBackupPlansResult',
    'get_backup_plans',
    'get_backup_plans_output',
]

@pulumi.output_type
class GetBackupPlansResult:
    """
    A collection of values returned by getBackupPlans.
    """
    def __init__(__self__, cluster_id=None, id=None, ids=None, output_file=None, plans=None):
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if plans and not isinstance(plans, list):
            raise TypeError("Expected argument 'plans' to be a list")
        pulumi.set(__self__, "plans", plans)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> builtins.str:
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def plans(self) -> Sequence['outputs.GetBackupPlansPlanResult']:
        return pulumi.get(self, "plans")


class AwaitableGetBackupPlansResult(GetBackupPlansResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBackupPlansResult(
            cluster_id=self.cluster_id,
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            plans=self.plans)


def get_backup_plans(cluster_id: Optional[builtins.str] = None,
                     output_file: Optional[builtins.str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBackupPlansResult:
    """
    This data source provides the Cassandra Backup Plans of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.128.0+.

    > **DEPRECATED:**  This data source has been [deprecated](https://www.alibabacloud.com/help/en/apsaradb-for-cassandra/latest/cassandra-delisting-notice) from version `1.220.0`.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.cassandra.get_backup_plans(cluster_id="example_value")
    pulumi.export("firstCassandraBackupPlanId", example.plans[0].id)
    ```


    :param builtins.str cluster_id: The ID of the cluster for the backup.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cassandra/getBackupPlans:getBackupPlans', __args__, opts=opts, typ=GetBackupPlansResult).value

    return AwaitableGetBackupPlansResult(
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'),
        plans=pulumi.get(__ret__, 'plans'))
def get_backup_plans_output(cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                            output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetBackupPlansResult]:
    """
    This data source provides the Cassandra Backup Plans of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.128.0+.

    > **DEPRECATED:**  This data source has been [deprecated](https://www.alibabacloud.com/help/en/apsaradb-for-cassandra/latest/cassandra-delisting-notice) from version `1.220.0`.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.cassandra.get_backup_plans(cluster_id="example_value")
    pulumi.export("firstCassandraBackupPlanId", example.plans[0].id)
    ```


    :param builtins.str cluster_id: The ID of the cluster for the backup.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:cassandra/getBackupPlans:getBackupPlans', __args__, opts=opts, typ=GetBackupPlansResult)
    return __ret__.apply(lambda __response__: GetBackupPlansResult(
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        output_file=pulumi.get(__response__, 'output_file'),
        plans=pulumi.get(__response__, 'plans')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .get_instance_attachments import *
from .get_instances import *
from .get_search_indexes import *
from .get_secondary_indexes import *
from .get_service import *
from .get_tables import *
from .get_tunnels import *
from .instance import *
from .instance_attachment import *
from .search_index import *
from .secondary_index import *
from .table import *
from .tunnel import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetBindingsBindingResult',
    'GetExchangesExchangeResult',
    'GetInstancesInstanceResult',
    'GetQueuesQueueResult',
    'GetStaticAccountsAccountResult',
    'GetVirtualHostsHostResult',
]

@pulumi.output_type
class GetBindingsBindingResult(dict):
    def __init__(__self__, *,
                 argument: builtins.str,
                 binding_key: builtins.str,
                 binding_type: builtins.str,
                 destination_name: builtins.str,
                 id: builtins.str,
                 instance_id: builtins.str,
                 source_exchange: builtins.str,
                 virtual_host_name: builtins.str):
        """
        :param builtins.str argument: X-match Attributes. Valid Values: All: Default Value, All the Message Header of Key-Value Pairs Stored in the Must Match. Any: at Least One Pair of the Message Header of Key-Value Pairs Stored in the Must Match. This Parameter Applies Only to Headers Exchange Other Types of Exchange Is Invalid. Other Types of Exchange Here Can Either Be an Arbitrary Value.
        :param builtins.str binding_key: The Binding Key. The Source of the Binding Exchange Non-Topic Type: Can Only Contain Letters, Lowercase Letters, Numbers, and the Dash (-), the Underscore Character (_), English Periods (.) and the at Sign (@). Length from 1 to 255 Characters. The Source of the Binding Exchange Topic Type: Can Contain Letters, Lowercase Letters, Numbers, and the Dash (-), the Underscore Character (_), English Periods (.) and the at Sign (@). If You Include the Hash (.
        :param builtins.str binding_type: The Target Binding Types.
        :param builtins.str destination_name: The Target Queue Or Exchange of the Name.
        :param builtins.str id: The ID of the Binding. The value formats as `<instance_id>:<virtual_host_name>:<source_exchange>:<destination_name>`.
        :param builtins.str instance_id: Instance Id.
        :param builtins.str source_exchange: The Source Exchange Name.
        :param builtins.str virtual_host_name: Virtualhost Name.
        """
        pulumi.set(__self__, "argument", argument)
        pulumi.set(__self__, "binding_key", binding_key)
        pulumi.set(__self__, "binding_type", binding_type)
        pulumi.set(__self__, "destination_name", destination_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "source_exchange", source_exchange)
        pulumi.set(__self__, "virtual_host_name", virtual_host_name)

    @property
    @pulumi.getter
    def argument(self) -> builtins.str:
        """
        X-match Attributes. Valid Values: All: Default Value, All the Message Header of Key-Value Pairs Stored in the Must Match. Any: at Least One Pair of the Message Header of Key-Value Pairs Stored in the Must Match. This Parameter Applies Only to Headers Exchange Other Types of Exchange Is Invalid. Other Types of Exchange Here Can Either Be an Arbitrary Value.
        """
        return pulumi.get(self, "argument")

    @property
    @pulumi.getter(name="bindingKey")
    def binding_key(self) -> builtins.str:
        """
        The Binding Key. The Source of the Binding Exchange Non-Topic Type: Can Only Contain Letters, Lowercase Letters, Numbers, and the Dash (-), the Underscore Character (_), English Periods (.) and the at Sign (@). Length from 1 to 255 Characters. The Source of the Binding Exchange Topic Type: Can Contain Letters, Lowercase Letters, Numbers, and the Dash (-), the Underscore Character (_), English Periods (.) and the at Sign (@). If You Include the Hash (.
        """
        return pulumi.get(self, "binding_key")

    @property
    @pulumi.getter(name="bindingType")
    def binding_type(self) -> builtins.str:
        """
        The Target Binding Types.
        """
        return pulumi.get(self, "binding_type")

    @property
    @pulumi.getter(name="destinationName")
    def destination_name(self) -> builtins.str:
        """
        The Target Queue Or Exchange of the Name.
        """
        return pulumi.get(self, "destination_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the Binding. The value formats as `<instance_id>:<virtual_host_name>:<source_exchange>:<destination_name>`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        Instance Id.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="sourceExchange")
    def source_exchange(self) -> builtins.str:
        """
        The Source Exchange Name.
        """
        return pulumi.get(self, "source_exchange")

    @property
    @pulumi.getter(name="virtualHostName")
    def virtual_host_name(self) -> builtins.str:
        """
        Virtualhost Name.
        """
        return pulumi.get(self, "virtual_host_name")


@pulumi.output_type
class GetExchangesExchangeResult(dict):
    def __init__(__self__, *,
                 attributes: Mapping[str, builtins.str],
                 auto_delete_state: builtins.bool,
                 create_time: builtins.str,
                 exchange_name: builtins.str,
                 exchange_type: builtins.str,
                 id: builtins.str,
                 instance_id: builtins.str,
                 virtual_host_name: builtins.str):
        """
        :param Mapping[str, builtins.str] attributes: The attributes.
        :param builtins.bool auto_delete_state: Indicates whether the Auto Delete attribute is configured.
        :param builtins.str create_time: The creation time.
        :param builtins.str exchange_name: The name of the exchange.
        :param builtins.str exchange_type: The type of the exchange.
        :param builtins.str id: The ID of the Exchange. Its value is same as Queue Name.
        :param builtins.str instance_id: The ID of the instance.
        :param builtins.str virtual_host_name: The name of virtual host where an exchange resides.
        """
        pulumi.set(__self__, "attributes", attributes)
        pulumi.set(__self__, "auto_delete_state", auto_delete_state)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "exchange_name", exchange_name)
        pulumi.set(__self__, "exchange_type", exchange_type)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "virtual_host_name", virtual_host_name)

    @property
    @pulumi.getter
    def attributes(self) -> Mapping[str, builtins.str]:
        """
        The attributes.
        """
        return pulumi.get(self, "attributes")

    @property
    @pulumi.getter(name="autoDeleteState")
    def auto_delete_state(self) -> builtins.bool:
        """
        Indicates whether the Auto Delete attribute is configured.
        """
        return pulumi.get(self, "auto_delete_state")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        The creation time.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="exchangeName")
    def exchange_name(self) -> builtins.str:
        """
        The name of the exchange.
        """
        return pulumi.get(self, "exchange_name")

    @property
    @pulumi.getter(name="exchangeType")
    def exchange_type(self) -> builtins.str:
        """
        The type of the exchange.
        """
        return pulumi.get(self, "exchange_type")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the Exchange. Its value is same as Queue Name.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="virtualHostName")
    def virtual_host_name(self) -> builtins.str:
        """
        The name of virtual host where an exchange resides.
        """
        return pulumi.get(self, "virtual_host_name")


@pulumi.output_type
class GetInstancesInstanceResult(dict):
    def __init__(__self__, *,
                 create_time: builtins.str,
                 expire_time: builtins.str,
                 id: builtins.str,
                 instance_id: builtins.str,
                 instance_name: builtins.str,
                 instance_type: builtins.str,
                 payment_type: builtins.str,
                 private_end_point: builtins.str,
                 public_endpoint: builtins.str,
                 renewal_duration: builtins.int,
                 renewal_duration_unit: builtins.str,
                 renewal_status: builtins.str,
                 status: builtins.str,
                 support_eip: builtins.bool):
        """
        :param builtins.str create_time: OrderCreateTime.
        :param builtins.str expire_time: ExpireTime.
        :param builtins.str id: The ID of the Instance.
        :param builtins.str instance_id: THe instance Id.
        :param builtins.str instance_name: THe instance name.
        :param builtins.str instance_type: The instance type.
        :param builtins.str payment_type: The Pay-as-You-Type Values Include: the Subscription of a Pre-Paid.
        :param builtins.str private_end_point: The private endPoint.
        :param builtins.str public_endpoint: The public dndpoint.
        :param builtins.int renewal_duration: Renewal duration.
        :param builtins.str renewal_duration_unit: Auto-Renewal Cycle Unit Values Include: Month: Month. Year: Years.
        :param builtins.str renewal_status: Renew status.
        :param builtins.str status: The status of the resource.
        :param builtins.bool support_eip: Whether to support eip.
        """
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "expire_time", expire_time)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "instance_name", instance_name)
        pulumi.set(__self__, "instance_type", instance_type)
        pulumi.set(__self__, "payment_type", payment_type)
        pulumi.set(__self__, "private_end_point", private_end_point)
        pulumi.set(__self__, "public_endpoint", public_endpoint)
        pulumi.set(__self__, "renewal_duration", renewal_duration)
        pulumi.set(__self__, "renewal_duration_unit", renewal_duration_unit)
        pulumi.set(__self__, "renewal_status", renewal_status)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "support_eip", support_eip)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        OrderCreateTime.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> builtins.str:
        """
        ExpireTime.
        """
        return pulumi.get(self, "expire_time")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the Instance.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        THe instance Id.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> builtins.str:
        """
        THe instance name.
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> builtins.str:
        """
        The instance type.
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> builtins.str:
        """
        The Pay-as-You-Type Values Include: the Subscription of a Pre-Paid.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter(name="privateEndPoint")
    def private_end_point(self) -> builtins.str:
        """
        The private endPoint.
        """
        return pulumi.get(self, "private_end_point")

    @property
    @pulumi.getter(name="publicEndpoint")
    def public_endpoint(self) -> builtins.str:
        """
        The public dndpoint.
        """
        return pulumi.get(self, "public_endpoint")

    @property
    @pulumi.getter(name="renewalDuration")
    def renewal_duration(self) -> builtins.int:
        """
        Renewal duration.
        """
        return pulumi.get(self, "renewal_duration")

    @property
    @pulumi.getter(name="renewalDurationUnit")
    def renewal_duration_unit(self) -> builtins.str:
        """
        Auto-Renewal Cycle Unit Values Include: Month: Month. Year: Years.
        """
        return pulumi.get(self, "renewal_duration_unit")

    @property
    @pulumi.getter(name="renewalStatus")
    def renewal_status(self) -> builtins.str:
        """
        Renew status.
        """
        return pulumi.get(self, "renewal_status")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="supportEip")
    def support_eip(self) -> builtins.bool:
        """
        Whether to support eip.
        """
        return pulumi.get(self, "support_eip")


@pulumi.output_type
class GetQueuesQueueResult(dict):
    def __init__(__self__, *,
                 attributes: Mapping[str, builtins.str],
                 auto_delete_state: builtins.bool,
                 create_time: builtins.str,
                 exclusive_state: builtins.bool,
                 id: builtins.str,
                 instance_id: builtins.str,
                 last_consume_time: builtins.str,
                 queue_name: builtins.str,
                 virtual_host_name: builtins.str):
        """
        :param Mapping[str, builtins.str] attributes: The attributes for the Queue.
        :param builtins.bool auto_delete_state: Specifies whether the Auto Delete attribute is configured.
        :param builtins.str create_time: CreateTime.
        :param builtins.bool exclusive_state: Specifies whether the queue is an exclusive queue.
        :param builtins.str id: The ID of the Queue. Its value is same as Queue Name.
        :param builtins.str instance_id: The ID of the instance.
        :param builtins.str last_consume_time: The last consume time.
        :param builtins.str queue_name: The queue name.
        :param builtins.str virtual_host_name: The name of the virtual host.
        """
        pulumi.set(__self__, "attributes", attributes)
        pulumi.set(__self__, "auto_delete_state", auto_delete_state)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "exclusive_state", exclusive_state)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "last_consume_time", last_consume_time)
        pulumi.set(__self__, "queue_name", queue_name)
        pulumi.set(__self__, "virtual_host_name", virtual_host_name)

    @property
    @pulumi.getter
    def attributes(self) -> Mapping[str, builtins.str]:
        """
        The attributes for the Queue.
        """
        return pulumi.get(self, "attributes")

    @property
    @pulumi.getter(name="autoDeleteState")
    def auto_delete_state(self) -> builtins.bool:
        """
        Specifies whether the Auto Delete attribute is configured.
        """
        return pulumi.get(self, "auto_delete_state")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        CreateTime.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="exclusiveState")
    def exclusive_state(self) -> builtins.bool:
        """
        Specifies whether the queue is an exclusive queue.
        """
        return pulumi.get(self, "exclusive_state")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the Queue. Its value is same as Queue Name.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="lastConsumeTime")
    def last_consume_time(self) -> builtins.str:
        """
        The last consume time.
        """
        return pulumi.get(self, "last_consume_time")

    @property
    @pulumi.getter(name="queueName")
    def queue_name(self) -> builtins.str:
        """
        The queue name.
        """
        return pulumi.get(self, "queue_name")

    @property
    @pulumi.getter(name="virtualHostName")
    def virtual_host_name(self) -> builtins.str:
        """
        The name of the virtual host.
        """
        return pulumi.get(self, "virtual_host_name")


@pulumi.output_type
class GetStaticAccountsAccountResult(dict):
    def __init__(__self__, *,
                 access_key: builtins.str,
                 create_time: builtins.str,
                 id: builtins.str,
                 instance_id: builtins.str,
                 master_uid: builtins.str,
                 password: builtins.str,
                 user_name: builtins.str):
        """
        :param builtins.str access_key: Access key.
        :param builtins.str create_time: Create time stamp. Unix timestamp, to millisecond level.
        :param builtins.str id: The `key` of the resource supplied above.The value is formulated as `<instance_id>:<access_key>`.
        :param builtins.str instance_id: InstanceId
        :param builtins.str master_uid: The ID of the user's primary account.
        :param builtins.str password: Static password.
        :param builtins.str user_name: Static username.
        """
        pulumi.set(__self__, "access_key", access_key)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "master_uid", master_uid)
        pulumi.set(__self__, "password", password)
        pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> builtins.str:
        """
        Access key.
        """
        return pulumi.get(self, "access_key")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        Create time stamp. Unix timestamp, to millisecond level.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The `key` of the resource supplied above.The value is formulated as `<instance_id>:<access_key>`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        InstanceId
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="masterUid")
    def master_uid(self) -> builtins.str:
        """
        The ID of the user's primary account.
        """
        return pulumi.get(self, "master_uid")

    @property
    @pulumi.getter
    def password(self) -> builtins.str:
        """
        Static password.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> builtins.str:
        """
        Static username.
        """
        return pulumi.get(self, "user_name")


@pulumi.output_type
class GetVirtualHostsHostResult(dict):
    def __init__(__self__, *,
                 id: builtins.str,
                 instance_id: builtins.str,
                 virtual_host_name: builtins.str):
        """
        :param builtins.str id: The ID of the Virtual Host.
        :param builtins.str instance_id: InstanceId.
        :param builtins.str virtual_host_name: VirtualHostName.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "virtual_host_name", virtual_host_name)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the Virtual Host.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        InstanceId.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="virtualHostName")
    def virtual_host_name(self) -> builtins.str:
        """
        VirtualHostName.
        """
        return pulumi.get(self, "virtual_host_name")


